@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: hint
-version: 0.3.3.4
-id: hint-0.3.3.4-925af69014fcaabfd54d3423e251bee6
+version: 0.3.3.6
+id: hint-0.3.3.6-4811beac8b61f8811b91ff94429f37e6
 
 license: BSD3
 copyright:
@@ -33,31 +33,31 @@ hidden-modules: Hint.Annotations Hint.GHC Hint.Base
                 Hint.Reflection Hint.Typecheck Hint.Sandbox Hint.SignalHandlers
                 Hint.Util
 trusted: False
-import-dirs: /usr/local/lib/ghc/hint-0.3.3.4
-library-dirs: /usr/local/lib/ghc/hint-0.3.3.4
-hs-libraries: HShint-0.3.3.4
+import-dirs: /usr/local/lib/ghc/hint-0.3.3.6
+library-dirs: /usr/local/lib/ghc/hint-0.3.3.6
+hs-libraries: HShint-0.3.3.6
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: MonadCatchIO-mtl-0.3.0.5-8901559f8f89c3c3946fdd839ae54ae8
-         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         directory-1.1.0.2-4b2070a8941d5c76e41241a2ac457927
-         extensible-exceptions-0.1.1.4-3d9bd197c43329612c640f24179a7f19
-         filepath-1.3.0.0-954c43b4f109cbd4121f1231c14d5cff
-         ghc-7.4.2-6bf4f6532d6ddd6d9292345f5811b0d5
-         ghc-mtl-1.0.1.1-c640bfbf51c0e4e113a7dd6da4780d10
-         ghc-paths-0.1.0.8-fe805223477a58f16f6dd6c1c6fe4446
-         haskell-src-1.0.1.5-c9f37378f049d27f8c9a8a35f331bb90
-         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
-         random-1.0.1.1-597e5fbb16214a2d52b559b0643d1749
-         unix-2.5.1.1-c23dadb7ccff9eeb5d1df0bd91909ca9
-         utf8-string-0.3.8-d5e5121211c1ffe304a6efae5f108415
+depends: MonadCatchIO-mtl-0.3.0.5-3513252c828addfd714c500eedad81c0
+         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
+         directory-1.2.0.1-1e5a1d00411e436c303c3932f4640124
+         extensible-exceptions-0.1.1.4-255a395b3b026cb94b23754e1c372785
+         filepath-1.3.0.1-b12cbe18566fe1532a1fda4c85e31cbe
+         ghc-7.6.3-fd258c9ca51dcf51b7dd445ef2ebea8e
+         ghc-mtl-1.0.1.2-b68cd896e003512884e9f4e22d082a3a
+         ghc-paths-0.1.0.8-f3c881377f2ea836eabc075a09d6485c
+         haskell-src-1.0.1.5-5158962fe58b880522089767d55a9906
+         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
+         random-1.0.1.1-49dee13e6169a73481e9624e99220b78
+         unix-2.6.0.1-eff76fcbf6509b60a4df5e8289027c63
+         utf8-string-0.3.8-4b98c0faca0296b4da4f390d8a63aa83
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-hint-0.3.3.4/html/hint.haddock
-haddock-html: /usr/local/share/doc/hs-hint-0.3.3.4/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-hint-0.3.3.6/html/hint.haddock
+haddock-html: /usr/local/share/doc/hs-hint-0.3.3.6/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
